@@ -2,7 +2,6 @@
 #define DTWCLUST_UNDIRECTEDGRAPH_HPP_
 
 #include <cstddef> // std::size_t
-#include <functional> // std::unary_function
 #include <memory>
 #include <unordered_map>
 #include <vector>
@@ -17,15 +16,9 @@ public:
     bool isComplete();
     bool isConnected();
 
-private:
     struct Vertex;
-    struct VertexHash : public std::unary_function<std::weak_ptr<Vertex>, std::size_t> {
-        std::size_t operator()(const std::weak_ptr<Vertex>& vertex_wp) const;
-    };
-    struct VertexEqual : public std::unary_function<std::weak_ptr<Vertex>, bool> {
-        bool operator()(const std::weak_ptr<Vertex>& left, const std::weak_ptr<Vertex>& right) const;
-    };
 
+private:
     void dfs(const std::shared_ptr<Vertex>& vertex);
 
     std::unordered_map<int, std::shared_ptr<Vertex>> vertices_;
